@@ -1,34 +1,39 @@
-"""
-Python wrapper for getting weather data from AccueWeather for Limited Trial package.
-"""
+"""Python wrapper for getting weather data from AccueWeather for Limited Trial."""
+
 from __future__ import annotations
 
-import json
 import logging
-from typing import Any, Dict, cast
+from http import HTTPStatus
+from typing import Any
 
+import orjson
 from aiohttp import ClientSession
 
 from .const import (
     ATTR_CURRENT_CONDITIONS,
-    ATTR_FORECAST,
+    ATTR_FORECAST_DAILY_5,
+    ATTR_FORECAST_HOURLY_12,
     ATTR_GEOPOSITION,
     ENDPOINT,
     HTTP_HEADERS,
-    HTTP_OK,
-    HTTP_UNAUTHORIZED,
     REMOVE_FROM_CURRENT_CONDITION,
     REMOVE_FROM_FORECAST,
     REQUESTS_EXCEEDED,
     TEMPERATURES,
     URLS,
 )
+from .exceptions import (
+    ApiError,
+    InvalidApiKeyError,
+    InvalidCoordinatesError,
+    RequestsExceededError,
+)
 
 _LOGGER = logging.getLogger(__name__)
 
 
 class AccuWeather:
-    """Main class to perform AccuWeather API requests"""
+    """Main class to perform AccuWeather API requests."""
 
     def __init__(
         self,
@@ -37,13 +42,12 @@ class AccuWeather:
         latitude: float | None = None,
         longitude: float | None = None,
         location_key: str | None = None,
-    ):
+    ) -> None:
         """Initialize."""
         if not self._valid_api_key(api_key):
             raise InvalidApiKeyError(
                 "Your API Key must be a 32-character hexadecimal string"
             )
-
         if not location_key:
             if not self._valid_coordinates(latitude, longitude):
                 raise InvalidCoordinatesError("Your coordinates are invalid")
@@ -61,24 +65,22 @@ class AccuWeather:
         latitude: float | int | None, longitude: float | int | None
     ) -> bool:
         """Return True if coordinates are valid."""
-        try:
-            assert isinstance(latitude, (int, float)) and isinstance(
-                longitude, (int, float)
-            )
-            assert abs(latitude) <= 90 and abs(longitude) <= 180
-        except (AssertionError, TypeError):
-            return False
-        return True
+        if (
+            isinstance(latitude, (int, float))
+            and isinstance(longitude, (int, float))
+            and abs(latitude) <= 90
+            and abs(longitude) <= 180
+        ):
+            return True
+        return False
 
     @staticmethod
     def _valid_api_key(api_key: str) -> bool:
         """Return True if API key is valid."""
-        try:
-            assert isinstance(api_key, str)
-            assert len(api_key) == 32
-        except AssertionError:
-            return False
-        return True
+        if isinstance(api_key, str) and len(api_key) == 32:
+            return True
+
+        return False
 
     @staticmethod
     def _construct_url(arg: str, **kwargs: str) -> str:
@@ -94,8 +96,10 @@ class AccuWeather:
         return {key: data[key] for key in data if key not in to_remove}
 
     @staticmethod
-    def _parse_forecast(data: dict, to_remove: tuple) -> list:
-        """Parse and clean forecast API response."""
+    def _parse_forecast_daily(
+        data: dict[str, Any], to_remove: tuple[str, ...]
+    ) -> list[dict[str, Any]]:
+        """Parse and clean daily forecast API response."""
         parsed_data = [
             {key: value for key, value in item.items() if key not in to_remove}
             for item in data["DailyForecasts"]
@@ -129,16 +133,27 @@ class AccuWeather:
             for key, value in day["Night"].items():
                 day[f"{key}Night"] = value
             day.pop("Night")
-
         return parsed_data
 
-    async def _async_get_data(self, url: str) -> dict[str, Any]:
-        """Retreive data from AccuWeather API."""
+    @staticmethod
+    def _parse_forecast_hourly(
+        data: list[dict[str, Any]], to_remove: tuple[str, ...]
+    ) -> list[dict[str, Any]]:
+        """Parse and clean hourly forecast API response."""
+        parsed_data = [
+            {key: value for key, value in item.items() if key not in to_remove}
+            for item in data
+        ]
+        return parsed_data
+
+    async def _async_get_data(self, url: str) -> Any:
+        """Retrieve data from AccuWeather API."""
         async with self._session.get(url, headers=HTTP_HEADERS) as resp:
-            if resp.status == HTTP_UNAUTHORIZED:
+            if resp.status == HTTPStatus.UNAUTHORIZED.value:
                 raise InvalidApiKeyError("Invalid API key")
-            if resp.status != HTTP_OK:
-                error_text = json.loads(await resp.text())
+            if resp.status != HTTPStatus.OK.value:
+                # pylint: disable=no-member
+                error_text = orjson.loads(await resp.text())
                 if error_text["Message"] == REQUESTS_EXCEEDED:
                     raise RequestsExceededError(
                         "The allowed number of requests has been exceeded"
@@ -148,11 +163,14 @@ class AccuWeather:
             data = await resp.json()
         if resp.headers["RateLimit-Remaining"].isdigit():
             self._requests_remaining = int(resp.headers["RateLimit-Remaining"])
-        # pylint: disable=deprecated-typing-alias
-        return cast(Dict[str, Any], data if isinstance(data, dict) else data[0])
+
+        if "hourly" in url:
+            return data
+
+        return data if isinstance(data, dict) else data[0]
 
     async def async_get_location(self) -> None:
-        """Retreive location data from AccuWeather."""
+        """Retrieve location data from AccuWeather."""
         url = self._construct_url(
             ATTR_GEOPOSITION,
             api_key=self._api_key,
@@ -164,7 +182,7 @@ class AccuWeather:
         self._location_name = data["LocalizedName"]
 
     async def async_get_current_conditions(self) -> dict[str, Any]:
-        """Retreive current conditions data from AccuWeather."""
+        """Retrieve current conditions data from AccuWeather."""
         if not self._location_key:
             await self.async_get_location()
         assert self._location_key is not None
@@ -177,18 +195,34 @@ class AccuWeather:
         return self._clean_current_condition(data, REMOVE_FROM_CURRENT_CONDITION)
 
     async def async_get_forecast(self, metric: bool = True) -> list[dict[str, Any]]:
-        """Retreive forecast data from AccuWeather."""
+        """Retrieve daily forecast data from AccuWeather."""
         if not self._location_key:
             await self.async_get_location()
         assert self._location_key is not None
         url = self._construct_url(
-            ATTR_FORECAST,
+            ATTR_FORECAST_DAILY_5,
             api_key=self._api_key,
             location_key=self._location_key,
             metric=str(metric),
         )
         data = await self._async_get_data(url)
-        return self._parse_forecast(data, REMOVE_FROM_FORECAST)
+        return self._parse_forecast_daily(data, REMOVE_FROM_FORECAST)
+
+    async def async_get_forecast_hourly(
+        self, metric: bool = True
+    ) -> list[dict[str, Any]]:
+        """Retrieve hourly forecast data from AccuWeather."""
+        if not self._location_key:
+            await self.async_get_location()
+        assert self._location_key is not None
+        url = self._construct_url(
+            ATTR_FORECAST_HOURLY_12,
+            api_key=self._api_key,
+            location_key=self._location_key,
+            metric=str(metric),
+        )
+        data = await self._async_get_data(url)
+        return self._parse_forecast_hourly(data, REMOVE_FROM_FORECAST)
 
     @property
     def location_name(self) -> str | None:
@@ -204,39 +238,3 @@ class AccuWeather:
     def requests_remaining(self) -> int | None:
         """Return number of remaining allowed requests."""
         return self._requests_remaining
-
-
-class ApiError(Exception):
-    """Raised when AccuWeather API request ended in error."""
-
-    def __init__(self, status: str):
-        """Initialize."""
-        super().__init__(status)
-        self.status = status
-
-
-class InvalidApiKeyError(Exception):
-    """Raised when API Key format is invalid."""
-
-    def __init__(self, status: str):
-        """Initialize."""
-        super().__init__(status)
-        self.status = status
-
-
-class InvalidCoordinatesError(Exception):
-    """Raised when coordinates are invalid."""
-
-    def __init__(self, status: str):
-        """Initialize."""
-        super().__init__(status)
-        self.status = status
-
-
-class RequestsExceededError(Exception):
-    """Raised when allowed number of requests has been exceeded."""
-
-    def __init__(self, status: str):
-        """Initialize."""
-        super().__init__(status)
-        self.status = status
